# VFG v 2.2.0

Changes to [VFG 0.2.0 ](../0_2_0) to enable:

- Latent variables in Bayesian networks
   - Discrete variables can be defined using `elements` (named elements list) or `cardinality` (number of elements)
   - Variable `role` field can be used to tag `latent` variables
- Variable roles also include `control_state`
- Initial state priors in factor `role` field
- Enforcement of the `version` field as the *schema* version, and locking it to "0.3.0".
